@@ -23,55 +23,63 @@
 #include "config.h"
 #include <gnome.h>
 #include <dirent.h>
+#include <games-clock.h>
+#include <gconf/gconf-client.h>
 
 #include "properties.h"
 #include "gataxx.h"
 #include "ataxx.h"
-#include "clock.h"
+
 
 static GtkWidget *propbox = NULL;
 
 extern GtkWidget *window;
 extern GtkWidget *time_display;
+extern GConfClient *gataxx_gconf_client;
 extern guint black_computer_level;
 extern guint white_computer_level;
 extern guint computer_speed;
 extern gint timer_valid;
 extern guint black_computer_id;
 extern guint white_computer_id;
-extern gchar tile_set[255];
-extern gchar tile_set_tmp[255];
+extern gchar *tile_set;
 extern gint8 pixmaps[7][7];
 extern gint animate;
 extern gint flip_pixmaps_id;
-extern gint flip_final;
+extern gboolean flip_final;
 
-guint t_black_computer_level;
-guint t_white_computer_level;
-gint t_animate;
-gint t_quick_moves;
-gint t_flip_final;
+gboolean quick_moves;
 gint response;
 
 int mapped = 0;
 
+gchar * gataxx_gconf_get_string (gchar *key);
+gint gataxx_gconf_get_int (gchar *key, gint default_int);
+gboolean gataxx_gconf_get_bool (gchar *key, gint default_bool);
+
 void load_properties ()
 {
-	black_computer_level = gnome_config_get_int
-		("/gataxx/Preferences/blacklevel=0");
-	white_computer_level = gnome_config_get_int
-		("/gataxx/Preferences/whitelevel=0");
-	strncpy (tile_set, gnome_config_get_string
-			("/gataxx/Preferences/tileset=classic.png"), 255);
-	animate = gnome_config_get_int ("/gataxx/Preferences/animate=2");
-	if (gnome_config_get_int ("/gataxx/Preferences/quickmoves=0")) {
+	black_computer_level =
+		gataxx_gconf_get_int ("/apps/gataxx/blacklevel", 0);
+
+	white_computer_level =
+		gataxx_gconf_get_int ("/apps/gataxx/whitelevel", 0);
+
+	tile_set = gataxx_gconf_get_string ("/apps/gataxx/tileset");
+	if (tile_set == NULL)
+		tile_set = "classic.png";
+
+	animate = gataxx_gconf_get_int ("/apps/gataxx/animate", 2);
+
+	if ((quick_moves =
+	     gataxx_gconf_get_bool ("/apps/gataxx/quickmoves", FALSE)))
+	{
 		computer_speed = COMPUTER_MOVE_DELAY / 2;
 	}
 	else {
 		computer_speed = COMPUTER_MOVE_DELAY;
 	}
-	flip_final = gnome_config_get_int
-		("/gataxx/Preferences/flipfinal=1");
+	flip_final = gataxx_gconf_get_bool ("/apps/gataxx/flipfinal", TRUE);
 	
 	switch (animate) {
 		case 0:
@@ -85,50 +93,33 @@ void load_properties ()
 	}
 }
 
-void reset_properties ()
-{
-	t_black_computer_level = black_computer_level = gnome_config_get_int
-		("/gataxx/Preferences/blacklevel=0");
-	t_white_computer_level = white_computer_level = gnome_config_get_int
-		("/gataxx/Preferences/whitelevel=0");
-        strncpy (tile_set_tmp, tile_set, 255);
-	t_animate = animate;
-	t_quick_moves = gnome_config_get_int
-		("/gataxx/Preferences/quickmoves");
-	t_flip_final = flip_final;
-}
-
 void save_properties ()
 {
-	gnome_config_set_int ("/gataxx/Preferences/blacklevel",
-			black_computer_level);
-	gnome_config_set_int ("/gataxx/Preferences/whitelevel",
-			white_computer_level);
-	gnome_config_set_int ("/gataxx/Preferences/quickmoves",
-			t_quick_moves);
-	gnome_config_set_string ("/gataxx/Preferences/tileset",
-			tile_set_tmp);
-	gnome_config_set_int ("/gataxx/Preferences/animate", animate);
-	gnome_config_set_int ("/gataxx/Preferences/flipfinal", flip_final);
-	
-	gnome_config_sync ();
+	gconf_client_set_int (gataxx_gconf_client, "/apps/gataxx/blacklevel",
+	                      black_computer_level, NULL);
+	gconf_client_set_int (gataxx_gconf_client, "/apps/gataxx/whitelevel",
+	                      white_computer_level, NULL);
+	gconf_client_set_bool (gataxx_gconf_client, "/apps/gataxx/quickmoves",
+	                       quick_moves, NULL);
+	gconf_client_set_string (gataxx_gconf_client, "/apps/gataxx/tileset",
+	                         tile_set, NULL);
+	gconf_client_set_int (gataxx_gconf_client, "/apps/gataxx/animate",
+	                      animate, NULL);
+	gconf_client_set_bool (gataxx_gconf_client, "/apps/gataxx/flipfinal",
+	                       flip_final, NULL);
 }
 
 void apply_changes ()
 {
 	guint i, j;
-	
-	if ((black_computer_level != t_black_computer_level) ||
-			(white_computer_level != t_white_computer_level)) {
-		clock_stop (CLOCK (time_display));
+
+	{	
+		games_clock_stop (GAMES_CLOCK (time_display));
 		gtk_widget_set_sensitive (time_display, FALSE);
-		clock_set_seconds (CLOCK (time_display), 0);
+		games_clock_set_seconds (GAMES_CLOCK (time_display), 0);
 		timer_valid = 0;
 	}
 
-	black_computer_level = t_black_computer_level;
-	white_computer_level = t_white_computer_level;
-	
 	if (black_computer_id) {
 		gtk_timeout_remove (black_computer_id);
 		black_computer_id = 0;
@@ -139,15 +130,14 @@ void apply_changes ()
 		white_computer_id = 0;
 	}
 	
-	if (t_quick_moves) {
+	if (quick_moves) {
 		computer_speed = COMPUTER_MOVE_DELAY / 2;
 	}
 	else {
 		computer_speed = COMPUTER_MOVE_DELAY;
 	}
 	
-	if (strcmp (tile_set, tile_set_tmp)) {
-		strncpy (tile_set, tile_set_tmp, 255);
+	{
 		load_pixmaps ();
 		for (i = 0; i < 7; i++)
 			for (j = 0; j < 7; j++)
@@ -160,8 +150,6 @@ void apply_changes ()
 				}
 	}
 	
-	animate = t_animate;
-	
 	if (flip_pixmaps_id) {
 		gtk_timeout_remove (flip_pixmaps_id);
 		flip_pixmaps_id = 0;
@@ -181,51 +169,51 @@ void apply_changes ()
 			break;
 	}
 	
-
-	flip_final = t_flip_final;
-	
 	check_computer_players ();
-	save_properties ();
 }
 
 void black_computer_level_select (GtkWidget *widget, gpointer data)
 {
-	if (((guint) data != t_black_computer_level) &&
+	if (((guint) data != black_computer_level) &&
 		       (GTK_TOGGLE_BUTTON (widget)->active)) {
-		t_black_computer_level = (guint) data;
+		black_computer_level = (guint) data;
 	}
+	save_properties ();
 	apply_changes ();
 }
 
 void white_computer_level_select (GtkWidget *widget, gpointer data)
 {
-	if (((guint) data != t_white_computer_level) &&
+	if (((guint) data != white_computer_level) &&
 		       (GTK_TOGGLE_BUTTON (widget)->active)) {
-		t_white_computer_level = (guint) data;
+		white_computer_level = (guint) data;
 	}
+	save_properties ();
 	apply_changes ();
 }
 
 void quick_moves_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
-		t_quick_moves = 1;
+		quick_moves = TRUE;
 	}
 	else {
-		t_quick_moves = 0;
+		quick_moves = FALSE;
 	}
 
+	save_properties ();
 	apply_changes ();
 }
 
 void flip_final_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
-		t_flip_final = 1;
+		flip_final = TRUE;
 	}
 	else {
-		t_flip_final = 0;
+		flip_final = FALSE;
 	}
+	save_properties ();
 	apply_changes ();
 }
 
@@ -233,13 +221,16 @@ void flip_final_select (GtkWidget *widget, gpointer data)
 void animate_select (GtkWidget *widget, gpointer data)
 {
 	if (GTK_TOGGLE_BUTTON (widget)->active) {
-		t_animate = (gint) data;
+		animate = (gint) data;
 	}
+
+	save_properties ();
 	apply_changes ();
 }
 
 void apply_cb (GtkWidget *widget, gpointer data)
 {
+	save_properties ();
 	apply_changes();
 }
 
@@ -250,9 +241,13 @@ void destroy_cb (GtkWidget *widget, gpointer data)
 
 void set_selection(GtkWidget *widget, gpointer data)
 {
-	if (strcmp ((gchar *)data, tile_set_tmp)) {
-	        strncpy(tile_set_tmp, data, 255);
-	}
+	if (tile_set)
+		g_free (tile_set);
+
+	tile_set = g_strdup ((char *) data);
+        
+	save_properties ();
+	apply_changes();
 }
 
 void free_str(GtkWidget *widget, void *data)
@@ -263,7 +258,7 @@ void free_str(GtkWidget *widget, void *data)
 void fill_menu(GtkWidget *menu)
 {
         struct dirent *e;
-	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, ("gataxx"), FALSE, NULL);
+	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, ("gataxx"), FALSE, NULL);
         DIR *dir;
         int itemno = 0;
 
@@ -315,7 +310,7 @@ void show_properties_dialog ()
 	propbox = gtk_dialog_new_with_buttons (_("Properties"),
 					       GTK_WINDOW (window),
 					       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
-					       _("Done"),
+					       GTK_STOCK_OK,
 					       GTK_RESPONSE_OK,
 					       NULL);
 	
@@ -325,10 +320,6 @@ void show_properties_dialog ()
 	g_signal_connect (G_OBJECT (propbox), "delete_event",
 			  G_CALLBACK (gtk_widget_destroy), propbox);
 	
-	vbox = gtk_vbox_new (FALSE, 5);
-	gtk_container_add (GTK_CONTAINER (propbox), vbox);
-	gtk_widget_show (vbox);
-	
 	notebook = gtk_notebook_new ();
 	gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook, TRUE, TRUE, 0);
@@ -514,7 +505,7 @@ void show_properties_dialog ()
 	gtk_widget_show (vbox);
 	
 	button = gtk_check_button_new_with_label (_("Flip final results"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), t_flip_final);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), flip_final);
 	g_signal_connect (G_OBJECT (button), "toggled",
 			  G_CALLBACK (flip_final_select), NULL);
 	gtk_widget_show (button);
@@ -548,3 +539,108 @@ void show_properties_dialog ()
 	gtk_widget_show (propbox);
 
 }	
+
+/* First checks gconf, then schema, then defaults to the value passed. */
+gint
+gataxx_gconf_get_int (gchar *key, gint default_int)
+{
+	GConfValue *value = NULL;
+	GConfValue *schema_value = NULL;
+	gint retval;
+
+	value = gconf_client_get (gataxx_gconf_client, key, NULL);
+	if (value == NULL)
+		return default_int;
+
+	if (value->type == GCONF_VALUE_INT) {
+		retval = gconf_value_get_int (value);
+		gconf_value_free (value);
+	}
+	else {
+		schema_value = gconf_client_get_default_from_schema
+			(gataxx_gconf_client, key, NULL);
+		if (schema_value == NULL) {
+			retval = default_int;
+		}
+		else {
+			retval = gconf_value_get_int (schema_value);
+		}
+		gconf_value_free (value);
+		gconf_value_free (schema_value);
+	}
+
+	return retval;
+}
+
+gboolean
+gataxx_gconf_get_bool (gchar *key, gboolean default_bool)
+{
+	GConfValue *value = NULL;
+	GConfValue *schema_value = NULL;
+	gboolean retval;
+
+	value = gconf_client_get (gataxx_gconf_client, key, NULL);
+	if (value == NULL)
+		return default_bool;
+
+	if (value->type == GCONF_VALUE_BOOL) {
+		retval = gconf_value_get_bool (value);
+		gconf_value_free (value);
+	}
+	else {
+		schema_value = gconf_client_get_default_from_schema
+			(gataxx_gconf_client, key, NULL);
+		if (schema_value == NULL) {
+			retval = default_bool;
+		}
+		else {
+			retval = gconf_value_get_bool (schema_value);
+		}
+		gconf_value_free (value);
+		gconf_value_free (schema_value);
+	}
+
+	return retval;
+}
+
+/* Returns gchar* you should free with g_free(). */
+/* First checks gconf, then schema. Returns NULL if not found in either. */
+gchar *
+gataxx_gconf_get_string (gchar *key)
+{
+	GConfValue *value = NULL;
+	GConfValue *schema_value = NULL;
+	gchar *retval = NULL;
+
+	value = gconf_client_get (gataxx_gconf_client, key, NULL);
+	if (value == NULL)
+		return NULL;
+
+	if (value->type == GCONF_VALUE_STRING) {
+		retval = g_strdup (gconf_value_get_string (value));
+		gconf_value_free (value);
+	}
+	else {
+		schema_value = gconf_client_get_default_from_schema
+			(gataxx_gconf_client, key, NULL);
+		if (schema_value == NULL) {
+			retval = NULL;
+		}
+		else {
+			retval = g_strdup (gconf_value_get_string (schema_value));
+		}
+		gconf_value_free (value);
+		gconf_value_free (schema_value);
+	}
+
+	return retval;
+}
+
+void reload_properties ()
+{
+	g_free (tile_set);
+	tile_set = NULL;
+	load_properties ();
+	apply_changes ();
+}
+
