@@ -21,13 +21,14 @@
 #ifndef TYPES_H
 #define TYPES_H
 
-#include <config.h>
 #include <gmodule.h>
 #include <gnome.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 
 
 #define STONE_SIZE 32
+#define SCROLL_SPEED 26
 
 
 typedef struct _GStonesPlugin       GStonesPlugin;
@@ -142,7 +143,7 @@ struct _GStonesObject
 
   guint               num_images;
   GdkPixmap         **image;
-  GdkImlibImage     **imlib_image;
+  GdkPixbuf     **pixbuf_image;
 };
 
 
@@ -211,8 +212,8 @@ struct _GStonesCave
 
   /* Some static information about this cave.  */
   GStonesGame      *game;
-  guint             width;
-  guint             height;
+  gint              width;
+  gint              height;
   gboolean          is_intermission;
   guint             diamond_score;
   guint             extra_diamond_score;
@@ -242,6 +243,9 @@ struct _GStonesCave
 
   GStonesCaveEntry  entry[CAVE_MAX_WIDTH+2][CAVE_MAX_HEIGHT+2];
 
+  /* Animated curtain */
+  GStonesObject *animated_curtain;
+
   /* This hash table holds an object context for every object that is used in
      this cave.  */
   GHashTable       *contexts;
